<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>CompletingEdit</name>
    <message>
        <source>Jump to PDF</source>
        <translation>PDFの該当箇所へジャンプ</translation>
    </message>
    <message>
        <source>No suggestions</source>
        <translation>候補がありません</translation>
    </message>
    <message>
        <source>Ignore word</source>
        <translation>単語を無視する</translation>
    </message>
</context>
<context>
    <name>ConfirmDelete</name>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Unable to delete</source>
        <translation>削除できません</translation>
    </message>
    <message>
        <source>Some of the auxiliary files could not be removed. Perhaps you don&apos;t have permission to delete them.</source>
        <translation>いくつかの補助ファイルが削除できませんでした。権限を確認してください。</translation>
    </message>
    <message>
        <source>Confirm file deletion</source>
        <translation>ファイルを削除してもよろしいですか？</translation>
    </message>
    <message>
        <source>Auxiliary files to be deleted:</source>
        <translation>補助ファイルは削除されました:</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation type="unfinished">全て選択</translation>
    </message>
    <message>
        <source>Select None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Find</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>検索 :</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>折り返して検索する(&amp;W)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>前を検索(&amp;b)</translation>
    </message>
    <message>
        <source>Search within &amp;selection</source>
        <translation>選択箇所を検索する(&amp;s)</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>検索結果を全て表示する(&amp;a)</translation>
    </message>
    <message>
        <source>Search all &amp;open files</source>
        <translation>開いているファイル全てを検索対象にする(&amp;o)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>大文字小文字を区別する(&amp;C)</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>完全一致(&amp;h)</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>正規表現(&amp;R)</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>一致する検索結果はありません</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(invalid)</translation>
    </message>
</context>
<context>
    <name>HardWrapDialog</name>
    <message>
        <source>Hard Wrap</source>
        <translation>折り返し(改行)</translation>
    </message>
    <message>
        <source>Wrap lines to:</source>
        <translation>折り返す文字数 :</translation>
    </message>
    <message>
        <source>Current window size</source>
        <translation>現在のウィンドウサイズ</translation>
    </message>
    <message>
        <source>Line length:</source>
        <translation>文字数 :</translation>
    </message>
    <message>
        <source>Re-wrap paragraphs</source>
        <translation>段落の折り返しをやり直す</translation>
    </message>
</context>
<context>
    <name>PDFDocument</name>
    <message>
        <source>Open Recent</source>
        <translation>最近開いたファイル</translation>
    </message>
    <message>
        <source>PDF file &quot;%1&quot; is locked; this is not currently supported.</source>
        <translation>PDFファイル&quot;%1&quot;がロックされています。この機能は現在実装されていません</translation>
    </message>
    <message>
        <source>Failed to load file &quot;%1&quot;; perhaps it is not a valid PDF document.</source>
        <translation>ファイル&quot;%1&quot;を読み込めません。正常なPDFファイルではないかもしれません</translation>
    </message>
    <message>
        <source>No SyncTeX data available</source>
        <translation>SyncTeXデータがありません</translation>
    </message>
    <message>
        <source>SyncTeX: &quot;%1&quot;</source>
        <translation>SyncTeX &quot;%1&quot;</translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation>%1[*] - %2</translation>
    </message>
    <message>
        <source>page %1 of %2</source>
        <translation>%2ページ中%1ページ</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1%</translation>
    </message>
    <message>
        <source>untitled.pdf[*]</source>
        <translation>untitled.pdf[*]</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>View</source>
        <translation>表示</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>表示</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>タイプセット</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>ツールバー</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>TeXworksについて</translation>
    </message>
    <message>
        <source>First Page</source>
        <translation>最初のページ</translation>
    </message>
    <message>
        <source>Home</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>前のページ</translation>
    </message>
    <message>
        <source>PgUp</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>次のページ</translation>
    </message>
    <message>
        <source>PgDown</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Last Page</source>
        <translation>最後のページ</translation>
    </message>
    <message>
        <source>End</source>
        <comment>shortcut key name, do not translate</comment>
        <translation></translation>
    </message>
    <message>
        <source>Go to Page...</source>
        <translation>ページを指定して移動</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation>拡大</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>縮小</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>ウィンドウサイズに合わせる</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>実際のサイズ</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>ウィンドウ幅に合わせる</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>元に戻す</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>繰り返す</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation>Ctrl+Shift+Z</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>切り取り</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>選択範囲を削除</translation>
    </message>
    <message>
        <source>Ctrl+Backspace</source>
        <translation>Ctrl+Backspace</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>タイプセット</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>積み重ねる</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>タイル</translation>
    </message>
    <message>
        <source>Go to Source</source>
        <translation>ソースの該当箇所へ</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation>Ctrl+&apos;</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>テンプレートから新規作成</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Full Screen</source>
        <translation>フルスクリーン表示</translation>
    </message>
    <message>
        <source>Ctrl+Shift+F</source>
        <translation>Ctrl+Shift+F</translation>
    </message>
    <message>
        <source>Magnify</source>
        <translation>拡大</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>スクロール</translation>
    </message>
    <message>
        <source>Select Text</source>
        <translation>テキストの選択</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>画像の選択</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworksのホームページへ</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>メーリングリストに投稿する</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>横に並べる</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>左に表示</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>右に表示</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>TeXworksを終了する</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>再度検索する</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>スクリプト</translation>
    </message>
    <message>
        <source>Update Scripts</source>
        <translation type="obsolete">スクリプトの更新</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>スクリプトの管理</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>スクリプトフォルダを開く</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Pdf...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to open the file in the default viewer for printing instead?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> (remember to close it again to avoid access problems)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PDFFindDialog</name>
    <message>
        <source>Find</source>
        <translation>検索する</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>一致する検索結果はありません</translation>
    </message>
    <message>
        <source>Find in PDF</source>
        <translation>PDFファイルを検索</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>検索:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>折り返して検索する(&amp;W)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>前を検索(&amp;b)</translation>
    </message>
    <message>
        <source>Find &amp;all occurrences</source>
        <translation>検索結果を全て表示する(&amp;a)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>大文字小文字を区別する(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Sync to source</source>
        <translation>ソースと同期する(&amp;S)</translation>
    </message>
</context>
<context>
    <name>PDFFontsDock</name>
    <message>
        <source>Name</source>
        <translation>フォント名</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message>
        <source>Subset</source>
        <translation>サブセット</translation>
    </message>
    <message>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <source>[none]</source>
        <translation>[なし]</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>はい</translation>
    </message>
    <message>
        <source>no</source>
        <translation>いいえ</translation>
    </message>
    <message>
        <source>[embedded]</source>
        <translation>[埋め込み]</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>フォント</translation>
    </message>
</context>
<context>
    <name>PDFInfoDock</name>
    <message>
        <source>PDF Info</source>
        <translation>PDFの情報</translation>
    </message>
</context>
<context>
    <name>PDFOutlineDock</name>
    <message>
        <source>No TOC</source>
        <translation>目次がありません</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>目次</translation>
    </message>
</context>
<context>
    <name>PDFWidget</name>
    <message>
        <source>Zoom In</source>
        <translation>拡大</translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation>縮小</translation>
    </message>
    <message>
        <source>Actual Size</source>
        <translation>実際のサイズ</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>ウィンドウ幅に合わせる</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>ウィンドウサイズに合わせる</translation>
    </message>
    <message>
        <source>Jump to Source</source>
        <translation>ソースの該当箇所へジャンプ</translation>
    </message>
    <message>
        <source>Go to Page</source>
        <translation>ページを指定して移動</translation>
    </message>
    <message>
        <source>Page number:</source>
        <translation>ページ番号:</translation>
    </message>
</context>
<context>
    <name>PrefsDialog</name>
    <message>
        <source>Choose Directory</source>
        <translation>ディレクトリを選択</translation>
    </message>
    <message>
        <source>New Tool</source>
        <translation>新規ツール</translation>
    </message>
    <message>
        <source>System default [%1]</source>
        <translation>システムのデフォルト [%1]</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>TeXworks Preferences</source>
        <translation>TeXworksの設定</translation>
    </message>
    <message>
        <source>General</source>
        <translation>全体</translation>
    </message>
    <message>
        <source>Toolbar buttons</source>
        <translation>ツールバーボタン</translation>
    </message>
    <message>
        <source>Small icons</source>
        <translation>小さなアイコン</translation>
    </message>
    <message>
        <source>Medium icons</source>
        <translation>中くらいのアイコン</translation>
    </message>
    <message>
        <source>Large icons</source>
        <translation>大きなアイコン</translation>
    </message>
    <message>
        <source>Show text as well as icons</source>
        <translation>アイコンの下にテキストを表示する</translation>
    </message>
    <message>
        <source>When launched, show</source>
        <translation>起動時には</translation>
    </message>
    <message>
        <source>New blank document</source>
        <translation>新しい空の文書を開く</translation>
    </message>
    <message>
        <source>Template selection dialog</source>
        <translation>テンプレート選択ダイアログを開く</translation>
    </message>
    <message>
        <source>File Open dialog</source>
        <translation>ファイル選択ダイアログを開く</translation>
    </message>
    <message>
        <source>Interface locale:</source>
        <translation>次回起動時の言語:</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>エディタ</translation>
    </message>
    <message>
        <source>Editor defaults</source>
        <translation>エディタのデフォルト</translation>
    </message>
    <message>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <source>Tab width:</source>
        <translation>タブ幅:</translation>
    </message>
    <message>
        <source>Line numbers</source>
        <translation>行番号表示</translation>
    </message>
    <message>
        <source>Wrap lines</source>
        <translation>行の折り返し</translation>
    </message>
    <message>
        <source>Syntax coloring:</source>
        <translation>構文の色付け:</translation>
    </message>
    <message>
        <source>Auto-Indent mode:</source>
        <translation>自動インデント:</translation>
    </message>
    <message>
        <source>Spell-check language:</source>
        <translation>スペルチェッカの言語:</translation>
    </message>
    <message>
        <source>Encoding:</source>
        <translation>エンコーディング:</translation>
    </message>
    <message>
        <source>Global editor options</source>
        <translation>エディタ全体のオプション</translation>
    </message>
    <message>
        <source>Highlight current line</source>
        <translation>現在カーソルのある行をハイライトする</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <source>Default scaling</source>
        <translation>デフォルトの倍率</translation>
    </message>
    <message>
        <source>Actual size</source>
        <translation>実際のサイズ</translation>
    </message>
    <message>
        <source>Fit to Width</source>
        <translation>ウィンドウ幅に合わせる</translation>
    </message>
    <message>
        <source>Fit to Window</source>
        <translation>ウィンドウサイズに合わせる</translation>
    </message>
    <message>
        <source>Fixed scale:</source>
        <translation>倍率を固定する:</translation>
    </message>
    <message>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <source>Magnifying glass</source>
        <translation>拡大鏡</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>小</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>中</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>大</translation>
    </message>
    <message>
        <source>Circular magnifier</source>
        <translation>円形に拡大する</translation>
    </message>
    <message>
        <source>Screen resolution:</source>
        <translation>画面解像度:</translation>
    </message>
    <message>
        <source> dpi</source>
        <translation> dpi</translation>
    </message>
    <message>
        <source>Typesetting</source>
        <translation>タイプセット</translation>
    </message>
    <message>
        <source>Paths for TeX and related programs</source>
        <translation>TeXおよび関連プログラムのパス</translation>
    </message>
    <message>
        <source>Processing tools</source>
        <translation>タイプセットの方法</translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Default:</source>
        <translation>デフォルト:</translation>
    </message>
    <message>
        <source>Auto-hide output panel unless errors occur</source>
        <translation>エラーがなければ、ログを表示しない</translation>
    </message>
    <message>
        <source>Smart Quotes mode:</source>
        <translation>引用符の入力支援</translation>
    </message>
    <message>
        <source> px</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation type="unfinished">スクリプト</translation>
    </message>
    <message>
        <source>Security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow scripts to read all files (script and document files are always readable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow scripts to write files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow scripts to run system commands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable QtScript debugger</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>TeX documents (*.tex)</source>
        <translation>TeX文書(*.tex)</translation>
    </message>
    <message>
        <source>LaTeX documents (*.ltx)</source>
        <translation>LaTeX文書(*.ltx)</translation>
    </message>
    <message>
        <source>BibTeX databases (*.bib)</source>
        <translation>BibTeXデータベース(*.bib)</translation>
    </message>
    <message>
        <source>Style files (*.sty)</source>
        <translation>スタイルファイル(*.sty)</translation>
    </message>
    <message>
        <source>Class files (*.cls)</source>
        <translation>クラスファイル(*.cls)</translation>
    </message>
    <message>
        <source>Documented macros (*.dtx)</source>
        <translation>文書化されたマクロ(*.dtx)</translation>
    </message>
    <message>
        <source>Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.log)</source>
        <translation>補助ファイル(*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.log)</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>テキストファイル(*.txt)</translation>
    </message>
    <message>
        <source>PDF documents (*.pdf)</source>
        <translation>PDFファイル(*.pdf)</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>全てのファイル</translation>
    </message>
</context>
<context>
    <name>ReplaceDialog</name>
    <message>
        <source>Replace</source>
        <translation>置換</translation>
    </message>
    <message>
        <source>Replace All</source>
        <translation>全て置換する</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>No recent search strings</source>
        <translation>一致する検索結果はありません</translation>
    </message>
    <message>
        <source>No recent replacement strings</source>
        <translation>一致する置換対象はありません</translation>
    </message>
    <message>
        <source>(invalid)</source>
        <translation>(invalid)</translation>
    </message>
    <message>
        <source>Replace:</source>
        <translation>置換対象:</translation>
    </message>
    <message>
        <source>With:</source>
        <translation>置換結果:</translation>
    </message>
    <message>
        <source>&amp;Wrap around</source>
        <translation>折り返して置換する(&amp;b)</translation>
    </message>
    <message>
        <source>Find &amp;backwards</source>
        <translation>前を検索する(&amp;h)</translation>
    </message>
    <message>
        <source>Replace within &amp;selection</source>
        <translation>選択範囲を置換する(&amp;s)</translation>
    </message>
    <message>
        <source>Replace in all &amp;open files</source>
        <translation>開いているファイル全てを置換対象にする(&amp;o)</translation>
    </message>
    <message>
        <source>&amp;Case sensitive</source>
        <translation>大文字小文字を区別する(&amp;C)</translation>
    </message>
    <message>
        <source>W&amp;hole words</source>
        <translation>完全一致(&amp;h)</translation>
    </message>
    <message>
        <source>&amp;Regular expression</source>
        <translation>正規表現(&amp;R)</translation>
    </message>
</context>
<context>
    <name>ScriptManager</name>
    <message>
        <source>Manage Scripts</source>
        <translation type="unfinished">スクリプトの管理</translation>
    </message>
    <message>
        <source>Standalone Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hook Scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Context: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Shortcut: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Language: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hook: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchResults</name>
    <message>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>行</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>開始</translation>
    </message>
    <message>
        <source>End</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>テキスト</translation>
    </message>
    <message>
        <source>Search Results</source>
        <translation>検索結果</translation>
    </message>
    <message>
        <source>Search Results - %1 (%2 found)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TWApp</name>
    <message>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>テンプレートから新規作成</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>最近開いたファイル</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>About </source>
        <translation>TeXworksについて</translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworksのホームページへ</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>メーリングリストに投稿する</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 is a simple environment for editing, typesetting, and previewing TeX documents.&lt;/p&gt;</source>
        <translation>&lt;p&gt;%1 はTeX文書の編集・タイプセット・プレビューのためのシンプルな統合環境です&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 (r.%2)</source>
        <translation type="obsolete">&lt;br&gt;バージョン %1 (r.%2)</translation>
    </message>
    <message>
        <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2.</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://hunspell.sourceforge.net/&quot;&gt;Hunspell&lt;/a&gt; spell checker by L&amp;#xE1;szl&amp;#xF3; N&amp;#xE9;meth.</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;br&gt;Concept and resources from &lt;a href=&quot;http://www.uoregon.edu/~koch/texshop/&quot;&gt;TeXShop&lt;/a&gt; by Richard Koch.</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;br&gt;&lt;a href=&quot;http://itexmac.sourceforge.net/SyncTeX.html&quot;&gt;SyncTeX&lt;/a&gt; technology by J&amp;#xE9;r&amp;#xF4;me Laurens.</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;br&gt;Some icons used are from the &lt;a href=&quot;http://tango.freedesktop.org/&quot;&gt;Tango Desktop Project&lt;/a&gt;.</source>
        <translation></translation>
    </message>
    <message>
        <source>&lt;p&gt;%1 translation kindly contributed by %2.</source>
        <translation>&lt;p&gt;%1の翻訳は%2によってなされました</translation>
    </message>
    <message>
        <source>[language name]</source>
        <translation>日本語</translation>
    </message>
    <message>
        <source>[translator&apos;s name/email]</source>
        <translation>田中健太 (Kenta TANAKA)</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>%1について</translation>
    </message>
    <message>
        <source>Unable to access &quot;%1&quot;; perhaps your browser or mail application is not properly configured?</source>
        <translation>&quot;%1&quot;にアクセスできませんでした。ブラウザの設定を確認してください</translation>
    </message>
    <message>
        <source>Unable to create window</source>
        <translation>ウィンドウを作成することができません</translation>
    </message>
    <message>
        <source>Something is badly wrong; %1 was unable to create a document window. The application will now quit.</source>
        <translation>%1は文書ウィンドウを作成できませんでした。何か設定が誤っているかもしれません。TeXworksは終了します</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>ファイルを開く</translation>
    </message>
    <message>
        <source>No default binary directory found</source>
        <translation>バイナリディレクトリが見つかりませんでした</translation>
    </message>
    <message>
        <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.</source>
        <translation>TeX関連プログラムがインストールされたディレクトリが見つかりません。&lt;p&gt;&lt;small&gt;プロセスを起動するためには、お使いのTeXディストリビューションに合わせたディレクトリ設定を[設定]-[タイプセット]ダイアログでおこなっておく必要があります</translation>
    </message>
    <message>
        <source>Unable to find help file.</source>
        <translation>ヘルプファイルが見つかりません</translation>
    </message>
    <message>
        <source>&lt;br&gt;Version %1 r.%2 (%3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;a href=&quot;http://qt.nokia.com/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by Qt Software, a division of Nokia Corporation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save File</source>
        <translation type="unfinished">ファイルの保存</translation>
    </message>
    <message>
        <source>Permission request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TWScriptAPI</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to execute system command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error executing system command: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System command execution is disabled (see Preferences)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&quot;%1&quot; could not be opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading all files is disabled (see Preferences)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; could not be opened for reading</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TWScriptable</name>
    <message>
        <source>unknown error</source>
        <translation>不明なエラー</translation>
    </message>
    <message>
        <source>Script &quot;%1&quot;: %2</source>
        <translation>スクリプト &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>Script result</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scripting languages currently available in this copy of %1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Scripts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TWSystemCmd</name>
    <message>
        <source>ERROR: failure code %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ERROR: exit code %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TagsDock</name>
    <message>
        <source>Tags</source>
        <translation>タグ</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>ブックマーク</translation>
    </message>
    <message>
        <source>Outline</source>
        <translation>文書のアウトライン</translation>
    </message>
    <message>
        <source>No tags</source>
        <translation>タグがありません</translation>
    </message>
</context>
<context>
    <name>TeXDocument</name>
    <message>
        <source>New document</source>
        <translation>新しい文書</translation>
    </message>
    <message>
        <source>Open Recent</source>
        <translation>最近開いた文書</translation>
    </message>
    <message>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>ファイルを開く</translation>
    </message>
    <message>
        <source>Cannot close window while tool is running</source>
        <translation type="obsolete">処理が続いているため、ウィンドウを閉じることができません</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>ファイルの保存</translation>
    </message>
    <message>
        <source>The document &quot;%1&quot; has been modified.
Do you want to save your changes?</source>
        <translation>ファイル&quot;%1&quot;はすでに存在します。変更を保存しますか？</translation>
    </message>
    <message>
        <source>Do you want to discard all changes to the document &quot;%1&quot;, and revert to the last saved version?</source>
        <translation>ファイル&quot;%1&quot;への変更を全て取り消し、最後に保存した状態へ戻しますか？</translation>
    </message>
    <message>
        <source>Revert</source>
        <translation>復旧</translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2.</source>
        <translation type="obsolete">ファイル&quot;%1&quot;が開けません: %2</translation>
    </message>
    <message>
        <source>Unrecognized encoding</source>
        <translation>解釈できない文字コードです</translation>
    </message>
    <message>
        <source>The text encoding %1 used in %2 is not supported.

It will be interpreted as %3 instead, which may result in incorrect text.</source>
        <translation>ファイル%2で使われている文字コード%1はサポートされていません。

かわりに%3として表示しますが、表示がおかしくなる場合があります</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded (%2)</source>
        <translation type="obsolete">ファイル&quot;%1&quot;が読み込まれました (%2)</translation>
    </message>
    <message>
        <source>File changed on disk</source>
        <translation>ディスク上でファイルが変更されました</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to discard your current changes, and reload the file from disk?</source>
        <translation>ファイル%1は他のプログラムによって変更されました。

編集した内容を全て取り消して、ファイルを再読み込みしますか？</translation>
    </message>
    <message>
        <source>%1 has been modified by another program.

Do you want to proceed with saving this file, overwriting the version on disk?</source>
        <translation>ファイル%1は他のプログラムによって変更されました。

編集内容を保存して、ファイルの内容を上書きしますか？</translation>
    </message>
    <message>
        <source>Document &quot;%1&quot; was not saved</source>
        <translation>文書&quot;%1&quot;は保存されていません</translation>
    </message>
    <message>
        <source>The text encoding %1 requested for %2 is not supported.

It will be saved as %3 instead, which may result in incorrect text.</source>
        <translation type="obsolete">ファイル%2が要求する文字コード%1はサポートされていません。

かわりに%3として保存しますが、表示がおかしくなる場合があります</translation>
    </message>
    <message>
        <source>Text cannot be converted</source>
        <translation>テキストの変換ができません</translation>
    </message>
    <message>
        <source>This document contains characters that cannot be represented in the encoding %1.

If you proceed, they will be replaced with default codes. Alternatively, you may wish to use a different encoding (such as UTF-8) to avoid loss of data.</source>
        <translation>この文書は文字コード%1に存在しない文字を含んでいます。

続行すると、文字はコード表記に置き換えられます。他の文字コード (UTF-8など) で保存したほうが、データの損失などを避けられるかもしれません</translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2.</source>
        <translation type="obsolete">ファイル&quot;%1&quot;に書き込めません:
%2</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved (%2)</source>
        <translation type="obsolete">ファイル&quot;%1&quot;に保存されました(%2)</translation>
    </message>
    <message>
        <source>default encoding</source>
        <translation type="obsolete">デフォルトの文字コード</translation>
    </message>
    <message>
        <source>untitled-%1.tex</source>
        <translation></translation>
    </message>
    <message>
        <source>%1[*] - %2</source>
        <translation></translation>
    </message>
    <message>
        <source>Line %1 of %2; col %3</source>
        <translation>%2の%1行目、%3列目</translation>
    </message>
    <message>
        <source>Go to Line</source>
        <translation>行を指定して移動</translation>
    </message>
    <message>
        <source>Line number:</source>
        <translation>行番号:</translation>
    </message>
    <message>
        <source>Invalid regular expression</source>
        <translation>正規表現が正しくありません</translation>
    </message>
    <message>
        <source>Not found</source>
        <translation>見つかりません</translation>
    </message>
    <message numerus="yes">
        <source>Found %n occurrence(s)</source>
        <translation>
            <numerusform>%n 個見つかりました</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n occurrence(s)</source>
        <translation>
            <numerusform>%n 個</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n documents</source>
        <translation>
            <numerusform>%n 個の文書</numerusform>
        </translation>
    </message>
    <message>
        <source>Replaced %1 in %2</source>
        <translation>%2中の%1が置換されました</translation>
    </message>
    <message numerus="yes">
        <source>Replaced %n occurrence(s)</source>
        <translation>
            <numerusform>%n 個置換されました</numerusform>
        </translation>
    </message>
    <message>
        <source>Cannot process unsaved document</source>
        <translation>保存されていない文書を処理できません</translation>
    </message>
    <message>
        <source>Root document %1 is not readable</source>
        <translation>マスターファイル%1が読み込めません</translation>
    </message>
    <message>
        <source>%1 is not properly configured</source>
        <translation>%1の設定が適切になされていないようです</translation>
    </message>
    <message>
        <source>Unable to execute %1</source>
        <translation>%1を実行できません</translation>
    </message>
    <message>
        <source>The program &quot;%1&quot; was not found.</source>
        <translation>プログラム&quot;%1&quot;が見つかりません</translation>
    </message>
    <message>
        <source>Searched in directories:</source>
        <translation>ディレクトリから検索:</translation>
    </message>
    <message>
        <source>Check configuration of the %1 tool and path settings in the Preferences dialog.</source>
        <translation>&quot;%1&quot;の設定とパスを[設定]ダイアログで確認してください</translation>
    </message>
    <message>
        <source>Hide Output Panel</source>
        <translation>ログ出力パネルを隠す</translation>
    </message>
    <message>
        <source>Show Output Panel</source>
        <translation>ログ出力パネルを表示する</translation>
    </message>
    <message>
        <source>Set engine to &quot;%1&quot;</source>
        <translation>&quot;%1&quot;で処理する</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; not defined</source>
        <translation>&quot;%1&quot;は定義されていません</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>ファイルが見つかりません</translation>
    </message>
    <message>
        <source>No auxiliary files associated with this document at the moment.</source>
        <translation>現在、この文書に対応する補助ファイルはありません</translation>
    </message>
    <message>
        <source>untitled.tex[*]</source>
        <translation></translation>
    </message>
    <message>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <source>Spelling</source>
        <translation>スペルチェック</translation>
    </message>
    <message>
        <source>Change Case</source>
        <translation>大文字小文字を変換する</translation>
    </message>
    <message>
        <source>Typeset</source>
        <comment>menu title</comment>
        <translation>タイプセット</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>ウィンドウ</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>表示</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>フォーマット</translation>
    </message>
    <message>
        <source>Auto-indent Mode</source>
        <translation>自動インデント</translation>
    </message>
    <message>
        <source>Syntax Coloring</source>
        <translation>構文の色付け</translation>
    </message>
    <message>
        <source>Smart Quotes</source>
        <translation>引用符の形式</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>Typeset Toolbar</source>
        <translation>タイプセットツールバー</translation>
    </message>
    <message>
        <source>Edit Toolbar</source>
        <translation>編集ツールバー</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新規作成</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>開く</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <source>Ctrl+Shift+S</source>
        <translation></translation>
    </message>
    <message>
        <source>Revert to Saved</source>
        <translation>保存した内容を取り消す</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>元に戻す</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>繰り返す</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Z</source>
        <translation></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>切り取り</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>選択範囲を削除</translation>
    </message>
    <message>
        <source>Typeset</source>
        <translation>タイプセット</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <comment>action</comment>
        <translation></translation>
    </message>
    <message>
        <source>Find...</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Again</source>
        <translation>再度検索する</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation></translation>
    </message>
    <message>
        <source>Replace...</source>
        <translation>置換</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Find</source>
        <translation>コピーして検索する</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Copy to Replace</source>
        <translation>コピーして置換する</translation>
    </message>
    <message>
        <source>Ctrl+Shift+E</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to Line...</source>
        <translation>行を指定して移動</translation>
    </message>
    <message>
        <source>Ctrl+L</source>
        <translation></translation>
    </message>
    <message>
        <source>Find Selection</source>
        <translation>選択範囲を検索する</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation></translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>全て選択</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <source>Font...</source>
        <translation>フォント</translation>
    </message>
    <message>
        <source>Indent</source>
        <translation>インデント</translation>
    </message>
    <message>
        <source>Ctrl+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Unindent</source>
        <translation>インデントの解除</translation>
    </message>
    <message>
        <source>Ctrl+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>コメントアウト</translation>
    </message>
    <message>
        <source>Ctrl+Shift+]</source>
        <translation></translation>
    </message>
    <message>
        <source>Uncomment</source>
        <translation>コメントアウトの解除</translation>
    </message>
    <message>
        <source>Ctrl+Shift+[</source>
        <translation></translation>
    </message>
    <message>
        <source>Wrap Lines</source>
        <translation>行の折り返し</translation>
    </message>
    <message>
        <source>About TeXworks...</source>
        <translation>TeXworksについて</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>積み重ねる</translation>
    </message>
    <message>
        <source>Tile</source>
        <translation>タイル</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>設定</translation>
    </message>
    <message>
        <source>Go to Preview</source>
        <translation>プレビューを表示</translation>
    </message>
    <message>
        <source>Ctrl+&apos;</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+\</source>
        <translation></translation>
    </message>
    <message>
        <source>New from Template...</source>
        <translation>テンプレートから新規作成</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation></translation>
    </message>
    <message>
        <source>Show Selection</source>
        <translation>選択範囲を表示</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <source>ALL UPPERCASE</source>
        <translation>全て大文字にする</translation>
    </message>
    <message>
        <source>all lowercase</source>
        <translation>全て小文字にする</translation>
    </message>
    <message>
        <source>Balance Delimiters</source>
        <translation>対応するカッコ内をハイライト</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation></translation>
    </message>
    <message>
        <source>Go to TeXworks home page</source>
        <translation>TeXworksのホームページへ</translation>
    </message>
    <message>
        <source>Email to the mailing list</source>
        <translation>メーリングリストに投稿する</translation>
    </message>
    <message>
        <source>Side by Side</source>
        <translation>横に並べる</translation>
    </message>
    <message>
        <source>Place on Left</source>
        <translation>左に表示</translation>
    </message>
    <message>
        <source>Place on Right</source>
        <translation>右に表示</translation>
    </message>
    <message>
        <source>Replace Again</source>
        <translation>再度置換する</translation>
    </message>
    <message>
        <source>Ctrl+Shift+R</source>
        <translation></translation>
    </message>
    <message>
        <source>Remove Aux Files...</source>
        <translation>補助ファイルを削除する</translation>
    </message>
    <message>
        <source>Quit TeXworks</source>
        <translation>TeXworksを終了する</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Toggle Case</source>
        <translation>大文字小文字の変換</translation>
    </message>
    <message>
        <source>Hard Wrap...</source>
        <translation>折り返し(改行)</translation>
    </message>
    <message>
        <source>Line Numbers</source>
        <translation>行番号</translation>
    </message>
    <message>
        <source>Process interrupted by user</source>
        <translation>処理はユーザによって中断されました</translation>
    </message>
    <message>
        <source>Console output</source>
        <translation>ログの表示</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>スクリプト</translation>
    </message>
    <message>
        <source>Show Scripts Folder</source>
        <translation>スクリプトフォルダを開く</translation>
    </message>
    <message>
        <source>Update Scripts</source>
        <translation type="obsolete">スクリプトの更新</translation>
    </message>
    <message>
        <source>Manage Scripts</source>
        <translation>スクリプトの管理</translation>
    </message>
    <message>
        <source>Scripting TeXworks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload Script List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto-Follow Focus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Scripts...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply to Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <comment>shortcut: Don&apos;t Save</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <comment>shortcut: Revert</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot read file &quot;%1&quot;:
%2</source>
        <translation type="unfinished">ファイル&quot;%1&quot;が開けません: %2 {1&quot;?} {2?}</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is constantly being modified by another program.

Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot write file &quot;%1&quot;:
%2</source>
        <translation type="unfinished">ファイル&quot;%1&quot;に書き込めません:
%2 {1&quot;?} {2?}</translation>
    </message>
    <message>
        <source>Error writing file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File &quot;%1&quot; saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Abort typesetting</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TeXHighlighter</name>
    <message>
        <source>default</source>
        <translation>デフォルト</translation>
    </message>
</context>
<context>
    <name>TemplateDialog</name>
    <message>
        <source>New File using Template</source>
        <translation>テンプレートを使って新規作成する</translation>
    </message>
    <message>
        <source>Choose template for the new document:</source>
        <translation>テンプレートを指定してください:</translation>
    </message>
</context>
<context>
    <name>ToolConfig</name>
    <message>
        <source>NewArgument</source>
        <translation>新しい引数</translation>
    </message>
    <message>
        <source>Select program file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; is not executable!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolConfigDialog</name>
    <message>
        <source>Tool Configuration</source>
        <translation>タイプセットの方法を設定する</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名前:</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation>プログラム:</translation>
    </message>
    <message>
        <source>Arguments:</source>
        <translation>引数:</translation>
    </message>
    <message>
        <source>View PDF after running</source>
        <translation>実行後、PDFを表示する</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
